@@ -228,10 +228,10 @@ def frequency_domain(x, sfreq: int = 5):
 
     # Peaks (Hz)
     peak = round(this_freq[np.argmax(this_psd)], 4)
-    stats.loc[len(stats)+1, :] = [peak, band + "_peak"]
+    stats.loc[len(stats) + 1, :] = [peak, band + "_peak"]
 
     # Power (ms**2)
-    power = np.trapz(x=this_freq, y=this_psd) * 1000000
+    power = np.trapezoid(x=this_freq, y=this_psd) * 1000000
     stats.loc[len(stats) + 1, :] = [power, band + "_power"]
 
     hf = stats.Values[stats.Metric == "hf_power"].values[0]
@@ -259,7 +259,7 @@ def outlier_detection(
         return True
 
     def mad_outlier_detection(x: np.ndarray, threshold: float) -> np.ndarray:
-        x = x - np.mean(x)
+        x = x - np.median(x)
         mad = scipy.stats.median_abs_deviation(x) * threshold
         return (x > mad) | (x < -mad)
 
